'use strict';

var _chai = require('chai');

var _createHtml = require('../createHtml');

var _createHtml2 = _interopRequireDefault(_createHtml);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-unused-expressions */


describe('createHtml', function () {
  it('should return the default template if no arguments are specified', function () {
    var expected = '\n<!DOCTYPE html>\n<html>\n  <head>\n    <meta charset="UTF-8">\n    <title>CarteBlanche</title>\n    <link rel="stylesheet" type="text/css" href="client-bundle.css" />\n  </head>\n  <body>\n    <div id=\'carte-blanche-root\'></div>\n\n\n    <script src="client-bundle.js"></script>\n    <script src="user-bundle.js"></script>\n  </body>\n</html>';
    (0, _chai.expect)((0, _createHtml2.default)()).to.equal(expected);
  });

  it('should handle the basePath option', function () {
    var basePath = '/examples';
    var expected = '\n<!DOCTYPE html>\n<html>\n  <head>\n    <meta charset="UTF-8">\n    <title>CarteBlanche</title>\n    <link rel="stylesheet" type="text/css" href="/examples/client-bundle.css" />\n  </head>\n  <body>\n    <div id=\'carte-blanche-root\'></div>\n\n\n    <script src="/examples/client-bundle.js"></script>\n    <script src="/examples/user-bundle.js"></script>\n  </body>\n</html>';
    (0, _chai.expect)((0, _createHtml2.default)({ basePath: basePath })).to.equal(expected);
  });

  it('should inject scripts', function () {
    var extraScripts = ['console.log("Hello World!")'];
    var expected = '\n<!DOCTYPE html>\n<html>\n  <head>\n    <meta charset="UTF-8">\n    <title>CarteBlanche</title>\n    <link rel="stylesheet" type="text/css" href="client-bundle.css" />\n  </head>\n  <body>\n    <div id=\'carte-blanche-root\'></div>\n    <script>console.log("Hello World!")</script>\n\n    <script src="client-bundle.js"></script>\n    <script src="user-bundle.js"></script>\n  </body>\n</html>';
    (0, _chai.expect)((0, _createHtml2.default)({ extraScripts: extraScripts })).to.equal(expected);
  });

  it('should inject styles', function () {
    var extraStyles = ['body { background: red; }'];
    var expected = '\n<!DOCTYPE html>\n<html>\n  <head>\n    <meta charset="UTF-8">\n    <title>CarteBlanche</title>\n    <link rel="stylesheet" type="text/css" href="client-bundle.css" />\n  </head>\n  <body>\n    <div id=\'carte-blanche-root\'></div>\n    <style>body { background: red; }</style>\n\n    <script src="client-bundle.js"></script>\n    <script src="user-bundle.js"></script>\n  </body>\n</html>';
    (0, _chai.expect)((0, _createHtml2.default)({ extraStyles: extraStyles })).to.equal(expected);
  });

  it('should inject the common chunk', function () {
    var commonsChunkFilename = 'commons.js';
    var expected = '\n<!DOCTYPE html>\n<html>\n  <head>\n    <meta charset="UTF-8">\n    <title>CarteBlanche</title>\n    <link rel="stylesheet" type="text/css" href="client-bundle.css" />\n  </head>\n  <body>\n    <div id=\'carte-blanche-root\'></div>\n\n    <script src="/commons.js"></script>\n    <script src="client-bundle.js"></script>\n    <script src="user-bundle.js"></script>\n  </body>\n</html>';
    (0, _chai.expect)((0, _createHtml2.default)({ commonsChunkFilename: commonsChunkFilename })).to.equal(expected);
  });
});